@@ -161,37 +161,16 @@ impl Core {
             .handle_timeout(&self.node, token, *self.section_chain().last_key())
     }
 
-    pub(crate) async fn add_to_filter(&mut self, wire_msg: &WireMsg) -> bool {
-        self.msg_filter.add_to_filter(wire_msg.msg_id()).await
-    }
-
     // Send message over the network.
-    pub(crate) async fn relay_message(&self, mut wire_msg: WireMsg) -> Result<Option<Command>> {
+    pub(crate) async fn relay_message(&self, mut wire_msg: WireMsg) -> Result<Command> {
         let dst_location = wire_msg.dst_location();
-        let (presumed_targets, dg_size) = delivery_group::delivery_targets(
+        let (targets, dg_size) = delivery_group::delivery_targets(
             dst_location,
             &self.node.name(),
             &self.section,
             &self.network,
         )?;
 
-        let mut targets = vec![];
-
-        for peer in presumed_targets {
-            if self
-                .msg_filter
-                .filter_outgoing(&wire_msg, peer.name())
-                .await
-                .is_new()
-            {
-                let _ = targets.push((*peer.name(), *peer.addr()));
-            }
-        }
-
-        if targets.is_empty() {
-            return Ok(None);
-        }
-
         trace!(
             "relay {:?} to first {:?} of {:?} (Section PK: {:?})",
             wire_msg,
@@ -201,16 +180,34 @@ impl Core {
         );
 
         let target_name = dst_location.name().ok_or(Error::CannotRoute)?;
+
+        // To avoid loop: if destination is to Node, targets are multiple, self is an elder,
+        //     self section prefix matches the destination name, then don't carry out a relay.
+        if self.is_elder()
+            && targets.len() > 1
+            && dst_location.is_to_node()
+            && self.section.prefix().matches(&target_name)
+        {
+            return Ok(Command::SendMessageDeliveryGroup {
+                recipients: Vec::new(),
+                delivery_group_size: 0,
+                wire_msg,
+            });
+        }
+
         let dst_pk = self.section_key_by_name(&target_name);
         wire_msg.set_dst_section_pk(dst_pk);
 
         let command = Command::SendMessageDeliveryGroup {
-            recipients: targets,
+            recipients: targets
+                .into_iter()
+                .map(|peer| (peer.name, peer.addr))
+                .collect(),
             delivery_group_size: dg_size,
             wire_msg,
         };
 
-        Ok(Some(command))
+        Ok(command)
     }
 
     // Setting the JoinsAllowed triggers a round Proposal::SetJoinsAllowed to update the flag.
